species package
===============

Submodules
----------

species.database module
-----------------------

.. automodule:: species.database
    :members:
    :undoc-members:
    :show-inheritance:

species.parallax module
-----------------------

.. automodule:: species.parallax
    :members:
    :undoc-members:
    :show-inheritance:

species.photometry module
-------------------------

.. automodule:: species.photometry
    :members:
    :undoc-members:
    :show-inheritance:

species.plot module
-------------------

.. automodule:: species.plot
    :members:
    :undoc-members:
    :show-inheritance:

species.read module
-------------------

.. automodule:: species.read
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: species
    :members:
    :undoc-members:
    :show-inheritance:
